@@ -119,6 +119,25 @@ class BarProvider:
         else:
             raise Exception("不支持的K线类型")
 
+    def create_bar_provider_by_date_24h(self, begin_date, end_date, interval, bar_type):
+        """
+        根据日期区间创建K线提供器
+        :param begin_date:
+        :param end_date:
+        :param interval:
+        :param bar_type:
+        """
+        self._interval = interval
+        self._bar_type = bar_type
+        if (bar_type == EnumBarType.second) | (bar_type == EnumBarType.minute) | (bar_type == EnumBarType.hour):
+            self._lst_date_time_slices = BaseBarHelper.create_in_day_date_time_slice_by_date_24h(begin_date,
+                                                                                                 end_date, interval,
+                                                                                                 bar_type)
+        elif bar_type == EnumBarType.day:
+            self._lst_date_time_slices = BaseBarHelper.create_out_day_date_time_slice_by_date(begin_date, end_date, interval, bar_type)
+        else:
+            raise Exception("不支持的K线类型")
+
     def create_night_am_pm_bar_provider_by_date(self, instrument_manager, instrument_id, begin_date, end_date, *instrument_ids):
         """
         根据日期区间创建K线提供器,只切分夜盘 上午盘 下午盘
@@ -149,6 +168,10 @@ class BarProvider:
         """
         return self._bar_series
 
+    @property
+    def date_time_slices(self):
+        return self._lst_date_time_slices
+
     def add_bar(self, new_bar):
         """
         添加bar
@@ -396,4 +419,4 @@ class BarProvider:
         to this type.
         """
         if event.type in self._handlers:
-            [handler(event) for handler in self._handlers[event.type]]
\ No newline at end of file
+            [handler(event) for handler in self._handlers[event.type]]
