@@ -265,10 +265,9 @@ class BaseBarHelper:
         :return:
         """
         lst_all_date_time_slices = []
-        begin_trading_date = TradingDayHelper.get_first_trading_day(begin_date)
-        end_trading_day = TradingDayHelper.get_last_trading_day(end_date)
-        lst_trading_days = TradingDayHelper.get_trading_days(begin_trading_date, end_trading_day)
-        for trading_day in lst_trading_days:
+        trading_day = begin_date
+        delta = datetime.timedelta(days=1)
+        while trading_day < end_date:
             time_slice = TimeSlice(begin_time=datetime.timedelta(hours=0, minutes=0, seconds=0), end_time=datetime.timedelta(hours=23, minutes=59, seconds=0))
             lst_trading_time_slices = [time_slice]
             lst_time_slices = BaseBarHelper.create_time_slice(lst_trading_time_slices, 0, interval, bar_type)
@@ -278,9 +277,9 @@ class BaseBarHelper:
                 date_time_slices.end_time = trading_day + time_slices.end_time
                 lst_all_date_time_slices.append(date_time_slices)
 
+            trading_day += delta
         return lst_all_date_time_slices
 
-
     @staticmethod
     def create_in_day_date_time_slice_by_date_consider_holiday(instrument_manager, instrument_id, begin_date, end_date, interval, bar_type, *instrument_ids):
         """
