@@ -15,6 +15,7 @@ from SapphireQuant.Core.TickSeries import TickSeries
 from SapphireQuant.DataProcessing.BarProvider import BarProvider
 from SapphireQuant.DataProcessing.BaseBarHelper import BaseBarHelper
 from SapphireQuant.DataProcessing.BinaryDayBarStream import BinaryDayBarStream
+from SapphireQuant.DataProcessing.BinaryDcTickStream import BinaryDcTickStream
 from SapphireQuant.DataProcessing.BinaryMinBarStream import BinaryMinBarStream
 from SapphireQuant.DataProcessing.BinaryTickStream import BinaryTickStream
 from SapphireQuant.Core.YfTimeHelper import YfTimeHelper
@@ -58,9 +59,14 @@ class QiDataController:
         try:
             file_path = os.path.join(path, trading_date.strftime('%Y%m%d'))
             file_path = os.path.join(file_path, instrument_id.split('.')[0] + ".tk")
-            if instrument_id.lower() != 'index':
-                instrument = self.instrument_manager[instrument_id.split('.')[0]]
-                tick_stream = BinaryTickStream(market, instrument_id, instrument.exchange_id, file_path)
+            if market == EnumMarket.期货:
+                if instrument_id.lower() != 'index':
+                    instrument = self.instrument_manager[instrument_id.split('.')[0]]
+                    tick_stream = BinaryTickStream(market, instrument_id, instrument.exchange_id, file_path)
+                    tick_stream.read_by_count(tick_series, 0, sys.maxsize)
+            elif market == EnumMarket.数字货币:
+                exchange_id = 'HUOBI'
+                tick_stream = BinaryDcTickStream(market, instrument_id, exchange_id, file_path)
                 tick_stream.read_by_count(tick_series, 0, sys.maxsize)
         except Exception as e:
             print(str(e))
@@ -71,12 +77,20 @@ class QiDataController:
         path = self.__future_tick_path
         tick_series = TickSeries()
         try:
-            file_path = os.path.join(path, trading_date.strftime('%Y%m%d'))
-            file_path = os.path.join(file_path, instrument_id.split('.')[0] + ".tk")
-            if instrument_id.lower() != 'index':
-                instrument = self.instrument_manager[instrument_id.split('.')[0]]
-                tick_stream = BinaryTickStream(market, instrument_id, instrument.exchange_id, file_path)
-                tick_stream.read_by_count(tick_series, 0, sys.maxsize)
+            if market == EnumMarket.期货:
+                file_path = os.path.join(path, trading_date.strftime('%Y%m%d'))
+                file_path = os.path.join(file_path, instrument_id.split('.')[0] + ".tk")
+                if instrument_id.lower() != 'index':
+                    instrument = self.instrument_manager[instrument_id.split('.')[0]]
+                    tick_stream = BinaryTickStream(market, instrument_id, instrument.exchange_id, file_path)
+                    tick_stream.read_by_count(tick_series, 0, sys.maxsize)
+            elif market == EnumMarket.数字货币:
+                file_path = os.path.join(path, trading_date.strftime('%Y%m%d'))
+                file_path = os.path.join(file_path, instrument_id.split('.')[0] + ".tk")
+                if instrument_id.lower() != 'index':
+                    exchange_id = 'HUOBI'
+                    tick_stream = BinaryDcTickStream(market, instrument_id, exchange_id, file_path)
+                    tick_stream.read_by_count(tick_series, 0, sys.maxsize)
         except Exception as e:
             print(str(e))
 
